# luxsci.AuthenticationApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**authentication**](AuthenticationApi.md#authentication) | **POST** /auth | 
[**revoke_authentication**](AuthenticationApi.md#revoke_authentication) | **DELETE** /auth | 

# **authentication**
> InlineResponse201 authentication(body=body)



In order to use any API commands, at any level, your client must first authenticate and obtain an authentication code. This authentication code can then be used to make one or more calls to API functions.    our authentication \"session\" can also be revoked, immediately invalidating all authentication codes received for it (i.e., this is a \"log out\").   In order to authenticate, you will need your API Token, API Key, and your API Host name. This API request is different from authenticated request in that you do not need to send a cookie, and the way that the request is signed is different.  See also [Authentication](/rest-api/mechanics.html#auth).

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.AuthenticationApi

body = luxsci.AuthBody() # AuthBody |  (optional)

try:
    api_response = api_instance.authentication(body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->authentication: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**AuthBody**](AuthBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **authentication**
> InlineResponse201 authentication(secret=secret, token=token, user=user, pass=pass)



In order to use any API commands, at any level, your client must first authenticate and obtain an authentication code. This authentication code can then be used to make one or more calls to API functions.    our authentication "session" can also be revoked, immediately invalidating all authentication codes received for it (i.e., this is a "log out").   In order to authenticate, you will need your API Token, API Key, and your API Host name. This API request is different from authenticated request in that you do not need to send a cookie, and the way that the request is signed is different.  See also [Authentication](/rest-api/mechanics.html#auth).

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = luxsci.AuthenticationApi()

try:
    api_response = api_instance.authentication(secret="SECRET",token="TOKEN")
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->authentication: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **secret** | **str**|  |
 **token** | **str**|  |
 **user** | **str**|  | [optional] 
 **pass** | **str**|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **revoke_authentication**
> InlineResponse200 revoke_authentication()



Revoke your authentication session and invalidate all authorization codes received. See also [Revocation](/rest-api/mechanics.html#revoke).

### Example
```python
from __future__ import print_function
import time
import luxsci
from luxsci.rest import ApiException
from pprint import pprint

# create an instance of the API class
secret_key = "SECRET_KEY"
token = "TOKEN"

luxsci_client = luxci.Client(secret_key, token)
api_instance = luxsci_client.AuthenticationApi


try:
    api_response = api_instance.revoke_authentication()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthenticationApi->revoke_authentication: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

